@@ -1,8 +1,8 @@
 #!/usr/bin/perl -w
 
 # Qemu Launcher is a GUI front-end to QEMU computer emulator.
-# Copyright (C) 2005, Erik Meitner <emeitner@f2o.org>
-# Copyright (C) 2006, Linas Žvirblis <0x0007@gmail.com>
+# Copyright (C) 2004 - 2005, Erik Meitner <emeitner@f2o.org>
+# Copyright (C) 2006 - 2007, Linas Žvirblis <0x0007@gmail.com>
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ use constant DEBUG_LEVEL => 1;
 
 # Application name and version
 my $application_name = gettext('Qemu Launcher');
-my $version = '1.7.3';
+my $version = '1.7.4';
 
 # Configuration directory, file, and name for default settings
 my $conf_dir = $ENV{'HOME'}.'/.qemu-launcher';
@@ -109,7 +109,7 @@ my %main_config_defaults = (
 	'imagedir'      => $ENV{'HOME'},
 	'qemupath'      => '/usr/bin/qemu',
 	'qemuimgpath'   => '/usr/bin/qemu-img',
-	'qemuctlpath'   => '',
+	'qemuctlpath'   => '/usr/bin/qemuctl',
 	'prelaunchcmd'  => ''
 );
 
@@ -1347,7 +1347,7 @@ sub create_disk_image
 	my $window = $gladexml->get_widget('diskimageswindow');
 	my $type = NULL;
 
-	foreach my $radiobutton ( qw/flat newcow oldcow vmware/ )
+	foreach my $radiobutton ( qw/flat newcow oldcow vmware cow2/ )
 	{
 		if ( ($gladexml->get_widget($radiobutton.'radiobutton'))->get_active() )
 		{
@@ -1391,7 +1391,7 @@ sub create_disk_image
 	elsif ( $type eq 'newcow' )
 	{
 		if( system( $main_config->{'qemuimgpath'}.
-			" create -f qcow \"$dir/$name\" ${size}M") )
+			" create -f qcow2 \"$dir/$name\" ${size}M") )
 		{
 			$error = TRUE;
 		}
@@ -1399,7 +1399,7 @@ sub create_disk_image
 	elsif ( $type eq 'oldcow' )
 	{
 		if (  system( $main_config->{'qemuimgpath'}.
-			" convert -f raw  \"$orig\" -O qcow \"$dir/$name\"") )
+			" convert -f raw  \"$orig\" -O qcow2 \"$dir/$name\"") )
 		{
 			$error = TRUE;
 		}
@@ -1407,7 +1407,15 @@ sub create_disk_image
 	elsif ( $type eq 'vmware' )
 	{
 		if ( system( $main_config->{'qemuimgpath'}.
-			" convert -f vmdk  \"$orig\" -O qcow \"$dir/$name\"") )
+			" convert -f vmdk  \"$orig\" -O qcow2 \"$dir/$name\"") )
+		{
+			$error = TRUE;
+		}
+	}
+	elsif ( $type eq 'cow2' )
+	{
+		if ( system( $main_config->{'qemuimgpath'}.
+			" convert -f qcow  \"$orig\" -O qcow2 \"$dir/$name\"") )
 		{
 			$error = TRUE;
 		}
@@ -2155,9 +2163,9 @@ $redirstreeview->append_column($column4);
 ($gladexml->get_widget('abouttext'))->set_markup(
 	"<span size=\"xx-large\"><b>$application_name $version</b></span>"
 	."\n\n"
-	.gettext("Copyright (C)")." 2005, Erik Meitner &#60;emeitner\@f2o.org\&#62;"
+	.gettext("Copyright (C)")." 2004, 2005, Erik Meitner &#60;erik\@wanderings.us\&#62;"
 	."\n"
-	.gettext("Copyright (C)")." 2006, Linas Žvirblis &#60;0x0007\@gmail.com\&#62;"
+	.gettext("Copyright (C)")." 2006, 2007, Linas Žvirblis &#60;0x0007\@gmail.com\&#62;"
 	."\n"
 	.gettext("QEMU is a trademark of Fabrice Bellard")
 	."\n\n"
@@ -2500,6 +2508,15 @@ $systypecombobox->signal_connect('changed' => sub {
 			return(TRUE);
 		});
 
+	($gladexml->get_widget('cow2radiobutton'))->
+		signal_connect ('clicked' => sub
+		{
+			$origimgfileentry->set_sensitive(TRUE);
+			$origimgbutton->set_sensitive(TRUE);
+			$imgsizespinbutton->set_sensitive(FALSE);
+			return(TRUE);
+		});
+
 	$origimgbutton->signal_connect('clicked', \&select_file, ['origimg', 'diskimageswindow']);
 	$imgdirbutton->signal_connect('clicked', \&select_directory, ['imgdir', 'diskimageswindow']);
 
